-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96, 5724-M24
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or
--  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

-- ------------------------------------------------------------------------------------
--
-- Script file to create schema (tables) for DB2 UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @SCHEMA@  = the schema name, eg MONITOR
-- @TSDIR@ = the directory or prefix for tablespace datafiles, eg DEFAULTTS
--    
--
-- Run the script in the DB2 command line processor with admin privileges.
--
-- USAGE:   db2 -tf createTables.sql
--
-- ------------------------------------------------------------------------------------

---------- EVENT SOURCE TABLES

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR(256)                      NOT NULL ,
  SOURCE_TYPE                        SMALLINT                                   ,
  PRIMARY KEY ( SOURCE_ID )
) 
-- IN DSTS32K
;

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(512)                               ,  
  DATA_SOURCE_JNDI                   VARCHAR(256)                               ,
  SCHEMA_NAME                        VARCHAR(128)                               ,
  HOST                               VARCHAR(128)                               ,
  PORT                               INTEGER                                    ,
  AUTH_ALIAS                         VARCHAR(128)                               ,  
  REMOTE_ID                          VARCHAR(256)                               ,
  IS_SECURITY_ENABLED                SMALLINT                                   ,
  IS_LOCAL                           SMALLINT                                   ,
  IS_EVENT_PRODUCER                  SMALLINT                                   ,
  IS_EVENT_CONSUMER                  SMALLINT                                   ,
  DE_NAME                            VARCHAR(256)                               ,  
  DE_PROPERTIES                      BLOB(1000M)                                ,
  PRIMARY KEY ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
)
-- IN DSTS32K
;

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID                          VARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       VARCHAR(512)                               ,  
  HOST                               VARCHAR(128)                               ,
  PORT                               INTEGER                                    ,
  AUTH_ALIAS                         VARCHAR(128)                               ,  
  SCOPE_TYPE                         SMALLINT                                   ,
  SCOPE_VALUE                        VARCHAR(512)                               ,
  EVENT_GROUP_PROFILE_LIST           VARCHAR(128)                               ,
  DE_NAME                            VARCHAR(256)                               ,  
  DE_PROPERTIES                      BLOB(1000M)                                ,
  PRIMARY KEY ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
) 
-- IN DSTS32K
;

CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  EVENT_SOURCE_ID                    VARCHAR(256)                      NOT NULL ,
  PROCESSING_MODE                    SMALLINT                                   ,
  RECORDING_EVENTS                   SMALLINT                                   ,
  IS_DELETED                         SMALLINT                                   ,
  ROUTER_TYPE                        VARCHAR(128)                               ,  
  ROUTING_PROPERTIES                 BLOB(1000M)                                ,
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) ,
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
) 
-- IN DSTS32K
;

CREATE TABLE @SCHEMA@.ES_SUBSCRIPTION_FILTERS_T
(
  MODEL_ID                           VARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                            NOT NULL ,
  EVENT_CONSUMER_ID                  VARCHAR(256)                      NOT NULL ,
  GU_ID                              VARCHAR(128)                      NOT NULL ,
  EVENT_FILTER                       VARCHAR(4000)                              ,  
  PRIMARY KEY ( MODEL_ID, VERSION, EVENT_CONSUMER_ID, GU_ID ) 
) 
-- IN DSTS32K
;
