-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96, 5724-M24
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or
--  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

-- Script file to create schema (tables) for 
-- DB2 z/OS v8
--
-----------------------------------------------------------------------
-- Following variables need to be changed for customization before 
-- running this script: 
-- @STOGRP@ = DB2 Storage group name (default is SYSDEFLT)
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@ = the schema name, eg MONITOR
--
--
-- Note: Tablespaces should be created with LOCKSIZE ROW to avoid 
--           deadlocks
--       Tablespaces should be created with CCSID UNICODE for
--       performance reasons and codepage coverage for user input
--
-- Run the script in the DB2 command line processor.
--
-- USAGE:   db2 -tf createTable_Monitor.sql
--
-- --------------------------------------------------------------------


-------------------
-- Create tables --
-------------------

-- Event Source Tables

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  SOURCE_TYPE SMALLINT,
  PRIMARY KEY (SOURCE_ID)
) IN @DB_NAME@.WBMON088;

CREATE UNIQUE INDEX @SCHEMA@.ES_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  DISPLAY_NAME VARCHAR(512),  
  DATA_SOURCE_JNDI VARCHAR(256),
  SCHEMA_NAME VARCHAR(128),
  HOST VARCHAR(128),
  PORT INTEGER,
  AUTH_ALIAS VARCHAR(128),  
  REMOTE_ID VARCHAR(256),
  IS_SECURITY_ENABLED SMALLINT,
  IS_LOCAL SMALLINT,
  IS_EVENT_PRODUCER SMALLINT,
  IS_EVENT_CONSUMER SMALLINT,
  DE_NAME VARCHAR(256),  
  DE_PROPERTIES BLOB(1000M),
  PRIMARY KEY (SOURCE_ID),
  FOREIGN KEY (SOURCE_ID) 
    REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON089;

CREATE UNIQUE INDEX @SCHEMA@.ES_BMON_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_BMON_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DE_PROPERTIES in ES_BMON_EVENT_SOURCE_T
CREATE AUX TABLE @SCHEMA@.ATLOB45
   IN @DB_NAME@.WBMLOB45
   STORES @SCHEMA@.ES_BMON_EVENT_SOURCE_T COLUMN DE_PROPERTIES;
-- auxiliary index for LOB column DE_PROPERTIES in ES_BMON_EVENT_SOURCE_T
CREATE UNIQUE INDEX @SCHEMA@.ATLOB45I
  ON @SCHEMA@.ATLOB45
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID VARCHAR(256) NOT NULL,
  DISPLAY_NAME VARCHAR(512),  
  HOST VARCHAR(128),
  PORT INTEGER,
  AUTH_ALIAS VARCHAR(128),  
  SCOPE_TYPE SMALLINT,
  SCOPE_VALUE VARCHAR(512),
  EVENT_GROUP_PROFILE_LIST VARCHAR(128),
  DE_NAME VARCHAR(256),  
  DE_PROPERTIES BLOB(1000M),
  PRIMARY KEY (SOURCE_ID),
  FOREIGN KEY (SOURCE_ID) 
    REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
    ON DELETE CASCADE
) IN @DB_NAME@.WBMON090;

CREATE UNIQUE INDEX @SCHEMA@.ES_CEI_EVENT_SOURCE_P 
  ON @SCHEMA@.ES_CEI_EVENT_SOURCE_T ( SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column DE_PROPERTIES in ES_CEI_EVENT_SOURCE_T
CREATE AUX TABLE @SCHEMA@.ATLOB46
   IN @DB_NAME@.WBMLOB46
   STORES @SCHEMA@.ES_CEI_EVENT_SOURCE_T COLUMN DE_PROPERTIES;
-- auxiliary index for LOB column DE_PROPERTIES in ES_CEI_EVENT_SOURCE_T
CREATE UNIQUE INDEX @SCHEMA@.ATLOB46I
  ON @SCHEMA@.ATLOB46
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID VARCHAR(128) NOT NULL,
  VERSION BIGINT NOT NULL,
  EVENT_SOURCE_ID VARCHAR(256) NOT NULL,
  PROCESSING_MODE SMALLINT,
  RECORDING_EVENTS SMALLINT,
  IS_DELETED SMALLINT,
  ROUTER_TYPE VARCHAR(128),  
  ROUTING_PROPERTIES BLOB(1000M),
  PRIMARY KEY (MODEL_ID, VERSION, EVENT_SOURCE_ID),
  FOREIGN KEY (EVENT_SOURCE_ID) 
    REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
) IN @DB_NAME@.WBMON091;

CREATE UNIQUE INDEX @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_P 
  ON @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T 
  ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

-- auxiliary table for LOB column ROUTING_PROPERTIES
CREATE AUX TABLE @SCHEMA@.ATLOB42
   IN @DB_NAME@.WBMLOB42
   STORES @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T COLUMN ROUTING_PROPERTIES;
-- auxiliary index for LOB column ROUTING_PROPERTIES
CREATE UNIQUE INDEX @SCHEMA@.ATLOB42I
  ON @SCHEMA@.ATLOB42
  USING STOGROUP @STOGRP@;

CREATE TABLE @SCHEMA@.ES_SUBSCRIPTION_FILTERS_T
(
  MODEL_ID VARCHAR(128) NOT NULL,
  VERSION BIGINT NOT NULL,
  EVENT_CONSUMER_ID VARCHAR(256) NOT NULL,
  GU_ID VARCHAR(128) NOT NULL,
  EVENT_FILTER VARCHAR(4000),
  PRIMARY KEY (MODEL_ID, VERSION, EVENT_CONSUMER_ID, GU_ID)
) IN @DB_NAME@.WBMON092;

CREATE UNIQUE INDEX @SCHEMA@.ES_SUBSCRIPTION_FILTERS_P 
  ON @SCHEMA@.ES_SUBSCRIPTION_FILTERS_T 
  ( MODEL_ID, VERSION, EVENT_CONSUMER_ID, GU_ID ) 
  NOT PADDED
  USING STOGROUP @STOGRP@;

COMMIT;

