-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT

--
--  ES
-- 

USE @DB_NAME@;

create TABLE @SCHEMA@.persistentlock (
    lockId integer not null,
    sequenceId integer not null,
    owner integer not null,
    moduleName varchar (250),
    compName varchar (250),
    method varchar (250),
    msgHandleString varchar (128),
    primary key (lockId,sequenceId));
    
--
-- FEM
--

-- *******************************************
-- create table FailedEvents and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEvents
  (MsgId            VARCHAR (255) NOT NULL,
   Destination_Module_Name  VARCHAR (255),
   Destination_Component_Name   VARCHAR (255),
   Destination_Method_Name  VARCHAR (255),
   Source_Module_Name       VARCHAR (255),
   Source_Component_Name    VARCHAR (255),
   ResubmitDestination      VARCHAR (512),
   InteractionType      VARCHAR (128),
   ExceptionDetails     NVARCHAR (1024),
   SessionId            VARCHAR (255),
   CorrelationId        VARCHAR (255),
   DeploymentTarget     VARCHAR (200),
   FailureTime          DATETIME NOT NULL,
   Status           INTEGER NOT NULL,
   EsQualified          SMALLINT,
   EventType        VARCHAR (10));

ALTER TABLE @SCHEMA@.FailedEvents
   ADD CONSTRAINT PK_FailedEvents PRIMARY KEY (MsgId);

CREATE INDEX INX_FEDest ON @SCHEMA@.FailedEvents
  (Destination_Module_Name,
   Destination_Component_Name,
   Destination_Method_Name);

CREATE INDEX INX_FESrc ON @SCHEMA@.FailedEvents
  (Source_Module_Name,
   Source_Component_Name);

CREATE INDEX INX_FESID ON @SCHEMA@.FailedEvents (SessionId);

CREATE INDEX INX_FEFTime ON @SCHEMA@.FailedEvents (FailureTime);

CREATE INDEX INX_FEESQualified ON @SCHEMA@.FailedEvents (EsQualified);

CREATE INDEX INX_FEEventType ON @SCHEMA@.FailedEvents (EventType);

-- *******************************************
-- create table FailedEventBOTypes and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventBOTypes
  (MsgId        VARCHAR (255) NOT NULL,
   BOType       VARCHAR (255) NOT NULL,
   Argument_Position    INTEGER NOT NULL);

ALTER TABLE @SCHEMA@.FailedEventBOTypes
   ADD CONSTRAINT PK_FailedEventBO PRIMARY KEY (MsgId, Argument_Position);

ALTER TABLE @SCHEMA@.FailedEventBOTypes
   ADD CONSTRAINT FK_FailedEventBO FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);

CREATE INDEX FailedEventBOTp ON @SCHEMA@.FailedEventBOTypes (BOType);

-- *******************************************
-- create table FailedEventMessage and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventMessage
  (MsgId        VARCHAR (255) NOT NULL,
   JserviceMessage  IMAGE);

ALTER TABLE @SCHEMA@.FailedEventMessage
   ADD CONSTRAINT PK_FailedEventMSG PRIMARY KEY (MsgId);

ALTER TABLE @SCHEMA@.FailedEventMessage
   ADD CONSTRAINT FK_FailedEventMSG FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);

-- *******************************************
-- create table FailedEventDetail and indexes
-- *******************************************
CREATE TABLE @SCHEMA@.FailedEventDetail
  (MsgId        VARCHAR (255) NOT NULL,
   Message      IMAGE,
   Parameters       IMAGE,
   ExceptionDetail  IMAGE,
   WrapperType          SMALLINT,
   ApplicationName  VARCHAR (255),
   CEITraceControl  VARCHAR (255),
   UserIdentity     VARCHAR(128),
   ExpirationTime   DATETIME);

ALTER TABLE @SCHEMA@.FailedEventDetail
   ADD CONSTRAINT PK_FailedEventDTL PRIMARY KEY (MsgId);

ALTER TABLE @SCHEMA@.FailedEventDetail
   ADD CONSTRAINT FK_FailedEventDTL FOREIGN KEY (MsgId) REFERENCES @SCHEMA@.FailedEvents(MsgId);
