-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or disclosure
--  restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT


USE @DB_NAME@;

-- *******************************************
-- AppScheduler
-- *******************************************
CREATE TABLE @SCHEMA@.WSCH_TASK
(
  TASKID             BIGINT                NOT NULL ,
  VERSION            VARCHAR(5)            NOT NULL ,
  ROW_VERSION        INT                   NOT NULL ,
  TASKTYPE           INT                   NOT NULL ,
  TASKSUSPENDED      TINYINT               NOT NULL ,
  CANCELLED          TINYINT               NOT NULL ,
  NEXTFIRETIME       BIGINT                NOT NULL ,
  STARTBYINTERVAL    VARCHAR(254)              NULL ,
  STARTBYTIME        BIGINT                    NULL ,
  VALIDFROMTIME      BIGINT                    NULL ,
  VALIDTOTIME        BIGINT                    NULL ,
  REPEATINTERVAL     VARCHAR(254)              NULL ,
  MAXREPEATS         INT                   NOT NULL ,
  REPEATSLEFT        INT                   NOT NULL ,
  TASKINFO           IMAGE                     NULL ,
  NAME               VARCHAR(254)          NOT NULL ,
  AUTOPURGE          INT                   NOT NULL ,
  FAILUREACTION      INT                       NULL ,
  MAXATTEMPTS        INT                       NULL ,
  QOS                INT                       NULL ,
  PARTITIONID        INT                       NULL ,
  OWNERTOKEN         VARCHAR(200)          NOT NULL ,
  CREATETIME         BIGINT                NOT NULL
) ;

ALTER TABLE @SCHEMA@.WSCH_TASK WITH NOCHECK ADD CONSTRAINT WSCH_TASK_PK PRIMARY KEY NONCLUSTERED ( TASKID );

CREATE INDEX WSCH_TASK_IDX1 ON @SCHEMA@.WSCH_TASK
(
  TASKID, OWNERTOKEN
) ;

CREATE CLUSTERED INDEX WSCH_TASK_IDX2 ON @SCHEMA@.WSCH_TASK
(
  NEXTFIRETIME ASC ,
  REPEATSLEFT ,
  PARTITIONID
) ;

CREATE TABLE @SCHEMA@.WSCH_TREG
(
  REGKEY             VARCHAR(254)          NOT NULL ,
  REGVALUE           VARCHAR(254)              NULL ,
  PRIMARY KEY ( REGKEY )
) ;

CREATE TABLE @SCHEMA@.WSCH_LMGR
(
  LEASENAME          VARCHAR(254)          NOT NULL ,
  LEASEOWNER         VARCHAR(254)          NOT NULL ,
  LEASE_EXPIRE_TIME  BIGINT                         ,
  DISABLED           VARCHAR(5)
) ;

ALTER TABLE @SCHEMA@.WSCH_LMGR WITH NOCHECK ADD CONSTRAINT WSCH_LMGR_PK PRIMARY KEY  NONCLUSTERED ( LEASENAME ) ;

CREATE TABLE @SCHEMA@.WSCH_LMPR
(
  LEASENAME          VARCHAR(254)          NOT NULL ,
  NAME               VARCHAR(254)          NOT NULL ,
  VALUE              VARCHAR(254)          NOT NULL
) ;

CREATE INDEX WSCH_LMPR_IDX1 ON @SCHEMA@.WSCH_LMPR
(
  LEASENAME, NAME
) ;


-- *******************************************
-- Customization
-- *******************************************
CREATE TABLE @SCHEMA@.BYTESTORE
  (ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   INITIALBYTES IMAGE,
   TIMESTAMP1 BIGINT NOT NULL,
   FILENAME VARCHAR(250),
   BACKINGCLASS VARCHAR(250),
   CHARENCODING VARCHAR(50),
   APPNAME VARCHAR(200),
   COMPONENTTNS VARCHAR(250),
   COMPONENTNAME VARCHAR(200),
   SCAMODULENAME VARCHAR(200),
   SCACOMPONENTNAME VARCHAR(200));

ALTER TABLE @SCHEMA@.BYTESTORE
  ADD CONSTRAINT PK_BYTESTORE PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME);

CREATE INDEX BYTESTORE_INDEX1 ON @SCHEMA@.BYTESTORE (
      COMPONENTTNS,
      COMPONENTNAME);

CREATE INDEX BYTESTORE_INDEX2 ON @SCHEMA@.BYTESTORE (
      ARTIFACTTYPE,
      COMPONENTTNS,
      COMPONENTNAME);

-- *******************************************
-- Create the BYTESTOREOVERFLOW table
-- *******************************************

CREATE TABLE @SCHEMA@.BYTESTOREOVERFLOW
  (ARTIFACTTYPE VARCHAR(50) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   SEQUENCENUMBER INTEGER NOT NULL,
   BYTES IMAGE);

ALTER TABLE @SCHEMA@.BYTESTOREOVERFLOW
  ADD CONSTRAINT PK_BYTESTOREOVERFL PRIMARY KEY (ARTIFACTTYPE, ARTIFACTTNS, ARTIFACTNAME, SEQUENCENUMBER);

-- *******************************************
-- Create the APPTIMESTAMP table
-- *******************************************

CREATE TABLE @SCHEMA@.APPTIMESTAMP
  (APPNAME VARCHAR(200) NOT NULL,
   TIMESTAMP1 BIGINT NOT NULL);

ALTER TABLE @SCHEMA@.APPTIMESTAMP
  ADD CONSTRAINT PK_APPTIMESTAMP PRIMARY KEY (APPNAME);
  
-- *******************************************
-- Create the CUSTPROPERTIES table
-- *******************************************

CREATE TABLE @SCHEMA@.CUSTPROPERTIES
  (PROPERTYID VARCHAR (128) NOT NULL,
   ARTIFACTTNS VARCHAR(250) NOT NULL,
   ARTIFACTNAME VARCHAR(200) NOT NULL,
   ARTIFACTTYPE VARCHAR(50) NOT NULL,
   PNAME VARCHAR(250) NOT NULL,
   PVALUE VARCHAR(250) NOT NULL,
   PTYPE VARCHAR (16) NOT NULL);

ALTER TABLE @SCHEMA@.CUSTPROPERTIES
  ADD CONSTRAINT PK_CUSTPROPERTIES PRIMARY KEY (PROPERTYID);

CREATE INDEX CUSTPROPERTIES_INDEX1 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS);  
      
CREATE INDEX CUSTPROPERTIES_INDEX2 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTNAME);
  
CREATE INDEX CUSTPROPERTIES_INDEX3 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      ARTIFACTNAME);  
      
CREATE INDEX CUSTPROPERTIES_INDEX4 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      PNAME);      
      
CREATE INDEX CUSTPROPERTIES_INDEX5 ON @SCHEMA@.CUSTPROPERTIES (
      ARTIFACTTYPE,
      ARTIFACTTNS,
      PNAME);      

-- *******************************************
-- DirectDeploy
-- *******************************************

create TABLE @SCHEMA@.d2d_item (
    id varchar(255) not null, 
    state varchar(20) not null,
    item_level int not null,
    module_name varchar(255),
    application_name varchar(255),
    version varchar(30), 
    wps_version varchar(10),
    new_app_name varchar(255),
    primary key (id));

create TABLE @SCHEMA@.d2d_progress (
    item_id varchar(255) not null,
    progress INTEGER,
    progress_msg varchar(255),
    progress_error_code  varchar(255),
    primary key (item_id));

create TABLE @SCHEMA@.d2d_content (
    item_id varchar(255) not null,
    pi  IMAGE,
    primary key (item_id));

create TABLE @SCHEMA@.d2d_metadata(
    item_id varchar(255) not null,
    name varchar(255) not null,
    value varchar(255) );

create TABLE @SCHEMA@.d2d_lock(
    item_lock character(1),
    lastUpdate datetime);

insert into @SCHEMA@.d2d_lock values ('x', null);

create TABLE @SCHEMA@.d2d_message(
    item_id varchar(255) not null,
    seq int not null,
    id  varchar(63),
    description varchar(1024),
    affected_resource varchar(255),
    location varchar(63),
    folder varchar(255),
    chr varchar(63),
    tag varchar(63),
    severity varchar(15),
    time datetime,
    primary key (item_id, seq));


-- *******************************************
-- ESDLoggerMediation
-- *******************************************

CREATE TABLE @SCHEMA@.MsgLog
  (TimeStamp DATETIME NOT NULL,
   MessageID VARCHAR(36) NOT NULL,
   MediationName VARCHAR(256) NOT NULL,
   ModuleName VARCHAR(256),
   Message TEXT,
   Version VARCHAR(10));

ALTER TABLE @SCHEMA@.MsgLog
  ADD CONSTRAINT PK_MSGLOG PRIMARY KEY (TimeStamp, MessageID, MediationName);


-- *******************************************
-- GovernanceRepository
-- *******************************************

CREATE TABLE @SCHEMA@.w_lit_double (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    litval float UNIQUE NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_dbl ON @SCHEMA@.w_lit_double (litval);

CREATE TABLE @SCHEMA@.w_lit_float (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    litval real UNIQUE NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_flt ON @SCHEMA@.w_lit_float (litval);

CREATE TABLE @SCHEMA@.w_lit_long (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    litval bigint UNIQUE NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_long ON @SCHEMA@.w_lit_long (litval);

CREATE TABLE @SCHEMA@.w_namespace (
    id int IDENTITY PRIMARY KEY CLUSTERED, 
    namespace nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL
);

CREATE UNIQUE INDEX idx_namespace ON @SCHEMA@.w_namespace
    (namespace ASC) ;

CREATE TABLE @SCHEMA@.w_obj_lit_any (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL,
    type_uri nvarchar(254) COLLATE Latin1_General_CS_AI NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_any ON @SCHEMA@.w_obj_lit_any (type_uri);

CREATE TABLE @SCHEMA@.w_obj_lit_date (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    litval datetime UNIQUE NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_date ON @SCHEMA@.w_obj_lit_date (litval);

CREATE TABLE @SCHEMA@.w_obj_lit_datetime (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    litval datetime UNIQUE NOT NULL
);

CREATE NONCLUSTERED INDEX idx_obj_time ON @SCHEMA@.w_obj_lit_datetime (litval);

CREATE TABLE @SCHEMA@.w_obj_lit_string (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    large image NULL,
    litval nvarchar(1024) COLLATE Latin1_General_CS_AI NULL,
    hash nvarchar(40) COLLATE Latin1_General_CS_AI NULL
);

CREATE NONCLUSTERED INDEX IDX_OBJ_STR ON @SCHEMA@.w_obj_lit_string
    (hash);

CREATE TABLE @SCHEMA@.w_uri (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    uri nvarchar(254) COLLATE Latin1_General_CS_AI UNIQUE NOT NULL,
    namespace_id int NOT NULL
);

CREATE UNIQUE INDEX idx_uri ON @SCHEMA@.w_uri (uri) ;
CREATE UNIQUE INDEX idx_uri_by_ns ON @SCHEMA@.w_uri (namespace_id,id);

CREATE TABLE @SCHEMA@.w_statement (
    id int IDENTITY PRIMARY KEY CLUSTERED,
    version_from int NOT NULL,
    version_to int NOT NULL,
    subj_id int NOT NULL,
    pred_id int NOT NULL,
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    partition_id int NOT NULL
);


CREATE NONCLUSTERED INDEX IDX_SMT_BY_SBJ ON @SCHEMA@.w_statement (subj_id, version_from, version_to);
CREATE NONCLUSTERED INDEX IDX_SMT_BY_FVR ON @SCHEMA@.w_statement (version_from);
CREATE NONCLUSTERED INDEX IDX_SBJ_BY_PRP ON @SCHEMA@.w_statement (pred_id, obj_id, partition_id);
CREATE NONCLUSTERED INDEX IDX_SBJ_BY_VAL ON @SCHEMA@.w_statement (obj_id, subj_id);
CREATE NONCLUSTERED INDEX IDX_VAL_BY_PRP ON @SCHEMA@.w_statement (subj_id, pred_id);

CREATE TABLE @SCHEMA@.w_version (
    id int NOT NULL,
    username nvarchar(64) COLLATE Latin1_General_CS_AI NOT NULL,
    change_time datetime NOT NULL,
    cl_gid nvarchar(36) COLLATE Latin1_General_CS_AI NULL,
    cl_lid nvarchar(10) COLLATE Latin1_General_CS_AI NULL,
    schema_ns_id int NULL,
    schema_rev int NULL,
    partition_id int NOT NULL
);

ALTER TABLE @SCHEMA@.w_version ADD CONSTRAINT pk_version PRIMARY KEY CLUSTERED (id, partition_id);

CREATE NONCLUSTERED INDEX IDX_VER_SCHEMA ON @SCHEMA@.w_version (schema_ns_id);

CREATE TABLE @SCHEMA@.w_artifact_blob (
 id NVARCHAR(254) COLLATE Latin1_General_CS_AI NOT NULL, 
 content IMAGE, 
 deleted SMALLINT,
 PRIMARY KEY(id)
);

ALTER TABLE @SCHEMA@.w_uri
    ADD CONSTRAINT W_URI_FK_NAMESP FOREIGN KEY (namespace_id) 
    REFERENCES @SCHEMA@.w_namespace (id) 
    ON UPDATE NO ACTION
    ON DELETE NO ACTION;

ALTER TABLE @SCHEMA@.w_version
    ADD CONSTRAINT W_VER_FK_NAMESP FOREIGN KEY (schema_ns_id) 
    REFERENCES @SCHEMA@.w_namespace (id) 
    ON UPDATE NO ACTION
    ON DELETE NO ACTION;
    
CREATE TABLE @SCHEMA@.w_locale (
    id int NOT NULL,
    locale nvarchar(8) COLLATE Latin1_General_CS_AI NOT NULL,
    PRIMARY KEY(id)
);

ALTER TABLE @SCHEMA@.w_locale ADD CONSTRAINT unique_locale UNIQUE (locale);

INSERT INTO @SCHEMA@.w_locale VALUES (1000, '');
INSERT INTO @SCHEMA@.w_locale VALUES (1001, 'en');
INSERT INTO @SCHEMA@.w_locale VALUES (1002, 'en-us');
INSERT INTO @SCHEMA@.w_locale VALUES (1003, 'en-uk');
INSERT INTO @SCHEMA@.w_locale VALUES (1004, 'en-gb');
INSERT INTO @SCHEMA@.w_locale VALUES (1032, 'cs');
INSERT INTO @SCHEMA@.w_locale VALUES (1064, 'es');
INSERT INTO @SCHEMA@.w_locale VALUES (1096, 'de');
INSERT INTO @SCHEMA@.w_locale VALUES (1128, 'de-de');
INSERT INTO @SCHEMA@.w_locale VALUES (1129, 'fr');
INSERT INTO @SCHEMA@.w_locale VALUES (1160, 'fr-ca-sk');
INSERT INTO @SCHEMA@.w_locale VALUES (1161, 'hu');
INSERT INTO @SCHEMA@.w_locale VALUES (1192, 'it');
INSERT INTO @SCHEMA@.w_locale VALUES (1224, 'ja');
INSERT INTO @SCHEMA@.w_locale VALUES (1256, 'ko');
INSERT INTO @SCHEMA@.w_locale VALUES (1288, 'pl');
INSERT INTO @SCHEMA@.w_locale VALUES (1320, 'pt-br');
INSERT INTO @SCHEMA@.w_locale VALUES (1352, 'ru');
INSERT INTO @SCHEMA@.w_locale VALUES (1384, 'zh');
INSERT INTO @SCHEMA@.w_locale VALUES (1416, 'zh-tw');
INSERT INTO @SCHEMA@.w_locale VALUES (1448, 'el');


-- Pattern tables for query optimization

CREATE TABLE @SCHEMA@.w_subj_pred_index (
    subj_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    predicate_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (subj_id, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_subj_obj_index (
    subj_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARBINARY(1024),
    obj_typ_cd int NOT NULL,
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (subj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_pred_subj_index (
    pred_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    subject_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (pred_id, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_pred_obj_index (
    pred_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    object_map VARBINARY(1024),
    obj_typ_cd int NOT NULL,
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (pred_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_obj_subj_index (
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    subject_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);

CREATE TABLE @SCHEMA@.w_obj_pred_index (
    obj_id int NOT NULL,
    obj_typ_cd int NOT NULL,
    predicate_map VARBINARY(1024),
    version_from int NOT NULL,
    version_to int NOT NULL,
    partition_id int NOT NULL REFERENCES @SCHEMA@.w_uri (id),
    PRIMARY KEY CLUSTERED (obj_id, obj_typ_cd, version_from, version_to, partition_id)
);



CREATE TABLE @SCHEMA@.w_dbversion(
    subsystem nvarchar(8) PRIMARY KEY CLUSTERED, 
    cur_version int NOT NULL 
);


-- *******************************************
-- Mediation
-- *******************************************
create TABLE @SCHEMA@.mediation_tickets (
    targetTicketID varchar(255) not null, 
    ticketEntry IMAGE, 
    version varchar(255) not null, 
    primary key (targetTicketID));

-- *******************************************
-- RelationshipService
-- *******************************************

CREATE TABLE @SCHEMA@.RELN_METADATA_T(RELATIONSHIP_NAME VARCHAR(255) NOT NULL, VERSION VARCHAR(10) NOT NULL);
CREATE UNIQUE INDEX RMT_RELN_NAME_I ON @SCHEMA@.RELN_METADATA_T (RELATIONSHIP_NAME);



CREATE TABLE @SCHEMA@.RELN_VIEW_META_T ( VIEW_NAME VARCHAR(255) NOT NULL,
                RELATIONSHIP_NAME VARCHAR(255) NOT NULL,
                ROLE_NAME VARCHAR(255) NOT NULL,
                VERSION VARCHAR(10) NOT NULL
            );                                      
CREATE UNIQUE INDEX RELN_VIEW_I ON @SCHEMA@.RELN_VIEW_META_T (RELATIONSHIP_NAME, ROLE_NAME);
