-- BEGIN COPYRIGHT
-- *************************************************************************
-- 
--  Licensed Materials - Property of IBM
--  5725-C94, 5725-C95, 5725-C96, 5724-M24
--  (C) Copyright IBM Corporation 2013. All Rights Reserved.
--  US Government Users Restricted Rights- Use, duplication or
--  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- 
-- *************************************************************************
-- END COPYRIGHT


--
-- Script file to create database and tablespaces for SQL Server UDB 
--
-- ------------------------------------------------------------------------------------
-- Following variables need to be changed for customization before running this script:
-- @DB_NAME@ = the database name, eg MONITOR
-- @SCHEMA@  = the schema name, eg MONITOR
--
--
-- Run the script in the sqlcmd command line processor
--
-- USAGE:  sqlcmd -U <userid> -P <password> -e -i createTables.sql
--
-- ------------------------------------------------------------------------------------

---------- EVENT SOURCE TABLES

USE @DB_NAME@;

CREATE TABLE @SCHEMA@.ES_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                     NOT NULL ,
  SOURCE_TYPE                        SMALLINT                              NULL ,
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID )
);

CREATE TABLE @SCHEMA@.ES_BMON_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       NVARCHAR(512)                          NULL ,  
  DATA_SOURCE_JNDI                   NVARCHAR(256)                          NULL ,
  SCHEMA_NAME                        NVARCHAR(128)                          NULL ,
  HOST                               NVARCHAR(128)                          NULL ,
  PORT                               INTEGER                                NULL ,
  AUTH_ALIAS                         NVARCHAR(128)                          NULL ,  
  REMOTE_ID                          NVARCHAR(256)                          NULL ,  
  IS_SECURITY_ENABLED                SMALLINT                               NULL ,
  IS_LOCAL                           SMALLINT                               NULL ,
  IS_EVENT_PRODUCER                  SMALLINT                               NULL ,
  IS_EVENT_CONSUMER                  SMALLINT                               NULL ,
  DE_NAME                            NVARCHAR(256)                          NULL ,  
  DE_PROPERTIES                      VARBINARY(MAX)                         NULL ,
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.ES_CEI_EVENT_SOURCE_T
(
  SOURCE_ID                          NVARCHAR(256)                      NOT NULL ,
  DISPLAY_NAME                       NVARCHAR(512)                          NULL ,  
  HOST                               NVARCHAR(128)                          NULL ,
  PORT                               INTEGER                                NULL ,
  AUTH_ALIAS                         NVARCHAR(128)                          NULL ,  
  SCOPE_TYPE                         SMALLINT                               NULL ,
  SCOPE_VALUE                        NVARCHAR(512)                          NULL ,
  EVENT_GROUP_PROFILE_LIST           NVARCHAR(128)                          NULL ,
  DE_NAME                            NVARCHAR(256)                          NULL ,  
  DE_PROPERTIES                      VARBINARY(MAX)                         NULL ,
  PRIMARY KEY NONCLUSTERED ( SOURCE_ID ) ,
  FOREIGN KEY ( SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID ) ON DELETE CASCADE
);

CREATE TABLE @SCHEMA@.ES_MM_EVENT_SOURCE_LIST_T
(
  MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                             NOT NULL ,
  EVENT_SOURCE_ID                    NVARCHAR(256)                      NOT NULL ,
  PROCESSING_MODE                    SMALLINT                               NULL ,
  RECORDING_EVENTS                   SMALLINT                               NULL ,
  IS_DELETED                         SMALLINT                               NULL ,
  ROUTER_TYPE                        NVARCHAR(128)                          NULL ,  
  ROUTING_PROPERTIES                 VARBINARY(MAX)                         NULL ,
  PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION, EVENT_SOURCE_ID ) ,
  FOREIGN KEY ( EVENT_SOURCE_ID ) REFERENCES @SCHEMA@.ES_EVENT_SOURCE_T( SOURCE_ID )
);

CREATE TABLE @SCHEMA@.ES_SUBSCRIPTION_FILTERS_T
(
  MODEL_ID                           NVARCHAR(128)                      NOT NULL ,
  VERSION                            BIGINT                             NOT NULL ,
  EVENT_CONSUMER_ID                  NVARCHAR(256)                      NOT NULL ,
  GU_ID                              NVARCHAR(128)                      NOT NULL ,  
  EVENT_FILTER                       NVARCHAR(4000)                         NULL ,  
  PRIMARY KEY NONCLUSTERED ( MODEL_ID, VERSION, EVENT_CONSUMER_ID, GU_ID )
);

